src/hotspot/share/runtime/mutexLocker.hpp
changeset 51548 35a6956f4243
parent 51520 ef7852ece52b
child 51608 625a5bdde0c5
--- a/src/hotspot/share/runtime/mutexLocker.hpp	Tue Aug 28 14:45:34 2018 -0400
+++ b/src/hotspot/share/runtime/mutexLocker.hpp	Tue Aug 28 16:04:54 2018 -0400
@@ -72,7 +72,7 @@
 extern Monitor* Safepoint_lock;                  // a lock used by the safepoint abstraction
 extern Monitor* Threads_lock;                    // a lock on the Threads table of active Java threads
                                                  // (also used by Safepoints too to block threads creation/destruction)
-extern Mutex*   NamedThreadsList_lock;           // a lock on the NamedThreads list
+extern Mutex*   NonJavaThreadsList_lock;         // a lock on the NonJavaThreads list
 extern Monitor* CGC_lock;                        // used for coordination between
                                                  // fore- & background GC threads.
 extern Monitor* STS_lock;                        // used for joining/leaving SuspendibleThreadSet.